@@ -22,18 +22,17 @@
 #include "thememanager.h"
 
 // General includes
-// #include <typeinfo>
+#include "kfourinline_debug.h"
 
 // Qt includes
 #include <QImage>
-#include <QPixmap>
 #include <QPainter>
+#include <QPixmap>
 #include <QRectF>
+#include <QStandardPaths>
 
 // KDE includes
-#include "kfourinline_debug.h"
-#include <kstandarddirs.h>
-#include <kconfiggroup.h>
+#include <KConfigGroup>
 #include <KLocalizedString>
 
 // Local includes
@@ -103,14 +102,14 @@ void ThemeManager::updateTheme(const QString &themefile)
   mPixmapCache.clear();
 
   // Process dirs
-  QString rcfile = KStandardDirs::locate("kwin4theme", themefile);
+  QString rcfile = QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("grafix/") + themefile);
   qCDebug(KFOURINLINE_LOG) << "ThemeManager LOAD with theme "<<rcfile;
 
   // Read config and SVG file for theme
   delete mConfig;
   mConfig = new KConfig(rcfile, KConfig::NoGlobals);
   QString svgfile = config(QStringLiteral("general")).readEntry("svgfile");
-  svgfile = KStandardDirs::locate("kwin4theme", svgfile);
+  svgfile = QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("grafix/") + svgfile);
   qCDebug(KFOURINLINE_LOG) << "Reading SVG master file  =" << svgfile;
   mAspectRatio     =  config(QStringLiteral("general")).readEntry("aspect-ratio", 1.0);
   qCDebug(KFOURINLINE_LOG) << "Aspect ratio =" << mAspectRatio;
